\name{A4}
\alias{A4}
\title{opens A4-sized window}
\description{
  opens a graphics window, 8.5 inches wide, 11 inches high
}

\usage{
A4 (...)
}

\arguments{
  \item{... }{arguments passed to R-function X11.
  }
}

\author{Karline Soetaert <karline.soetaert@nioz.nl>}

\keyword{device}

